==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftControllerManagerFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OpenShiftControllerManagerFluentImpl<A extends OpenShiftControllerManagerFluent<A>> extends BaseFluent<A> implements OpenShiftControllerManagerFluent<A>{
  public OpenShiftControllerManagerFluentImpl() {
  }
  public OpenShiftControllerManagerFluentImpl(OpenShiftControllerManager instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OpenShiftControllerManagerSpecBuilder spec;
  private OpenShiftControllerManagerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OpenShiftControllerManagerFluent.MetadataNested<A> withNewMetadata() {
    return new OpenShiftControllerManagerFluentImpl.MetadataNestedImpl();
  }
  public OpenShiftControllerManagerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OpenShiftControllerManagerFluentImpl.MetadataNestedImpl(item);
  }
  public OpenShiftControllerManagerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OpenShiftControllerManagerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OpenShiftControllerManagerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenShiftControllerManagerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OpenShiftControllerManagerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OpenShiftControllerManagerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OpenShiftControllerManagerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OpenShiftControllerManagerFluent.SpecNested<A> withNewSpec() {
    return new OpenShiftControllerManagerFluentImpl.SpecNestedImpl();
  }
  public OpenShiftControllerManagerFluent.SpecNested<A> withNewSpecLike(OpenShiftControllerManagerSpec item) {
    return new OpenShiftControllerManagerFluentImpl.SpecNestedImpl(item);
  }
  public OpenShiftControllerManagerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OpenShiftControllerManagerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OpenShiftControllerManagerSpecBuilder().build());
  }
  public OpenShiftControllerManagerFluent.SpecNested<A> editOrNewSpecLike(OpenShiftControllerManagerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenShiftControllerManagerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OpenShiftControllerManagerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OpenShiftControllerManagerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OpenShiftControllerManagerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OpenShiftControllerManagerFluent.StatusNested<A> withNewStatus() {
    return new OpenShiftControllerManagerFluentImpl.StatusNestedImpl();
  }
  public OpenShiftControllerManagerFluent.StatusNested<A> withNewStatusLike(OpenShiftControllerManagerStatus item) {
    return new OpenShiftControllerManagerFluentImpl.StatusNestedImpl(item);
  }
  public OpenShiftControllerManagerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OpenShiftControllerManagerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OpenShiftControllerManagerStatusBuilder().build());
  }
  public OpenShiftControllerManagerFluent.StatusNested<A> editOrNewStatusLike(OpenShiftControllerManagerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OpenShiftControllerManagerFluentImpl that = (OpenShiftControllerManagerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OpenShiftControllerManagerFluent.MetadataNested<N>> implements OpenShiftControllerManagerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OpenShiftControllerManagerSpecFluentImpl<OpenShiftControllerManagerFluent.SpecNested<N>> implements OpenShiftControllerManagerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OpenShiftControllerManagerSpec item) {
      this.builder = new OpenShiftControllerManagerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OpenShiftControllerManagerSpecBuilder(this);
    }
    OpenShiftControllerManagerSpecBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OpenShiftControllerManagerStatusFluentImpl<OpenShiftControllerManagerFluent.StatusNested<N>> implements OpenShiftControllerManagerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OpenShiftControllerManagerStatus item) {
      this.builder = new OpenShiftControllerManagerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OpenShiftControllerManagerStatusBuilder(this);
    }
    OpenShiftControllerManagerStatusBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftControllerManagerFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OpenShiftControllerManagerFluentImpl<A extends OpenShiftControllerManagerFluent<A>> extends BaseFluent<A> implements OpenShiftControllerManagerFluent<A>{
  public OpenShiftControllerManagerFluentImpl() {
  }
  public OpenShiftControllerManagerFluentImpl(OpenShiftControllerManager instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OpenShiftControllerManagerSpecBuilder spec;
  private OpenShiftControllerManagerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OpenShiftControllerManagerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new OpenShiftControllerManagerFluentImpl.MetadataNestedImpl();
  }
  public OpenShiftControllerManagerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OpenShiftControllerManagerFluentImpl.MetadataNestedImpl(item);
  }
  public OpenShiftControllerManagerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OpenShiftControllerManagerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OpenShiftControllerManagerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenShiftControllerManagerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OpenShiftControllerManagerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OpenShiftControllerManagerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OpenShiftControllerManagerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OpenShiftControllerManagerFluentImpl.SpecNested<A> withNewSpec() {
    return new OpenShiftControllerManagerFluentImpl.SpecNestedImpl();
  }
  public OpenShiftControllerManagerFluentImpl.SpecNested<A> withNewSpecLike(OpenShiftControllerManagerSpec item) {
    return new OpenShiftControllerManagerFluentImpl.SpecNestedImpl(item);
  }
  public OpenShiftControllerManagerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OpenShiftControllerManagerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OpenShiftControllerManagerSpecBuilder().build());
  }
  public OpenShiftControllerManagerFluentImpl.SpecNested<A> editOrNewSpecLike(OpenShiftControllerManagerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenShiftControllerManagerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OpenShiftControllerManagerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OpenShiftControllerManagerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OpenShiftControllerManagerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OpenShiftControllerManagerFluentImpl.StatusNested<A> withNewStatus() {
    return new OpenShiftControllerManagerFluentImpl.StatusNestedImpl();
  }
  public OpenShiftControllerManagerFluentImpl.StatusNested<A> withNewStatusLike(OpenShiftControllerManagerStatus item) {
    return new OpenShiftControllerManagerFluentImpl.StatusNestedImpl(item);
  }
  public OpenShiftControllerManagerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OpenShiftControllerManagerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OpenShiftControllerManagerStatusBuilder().build());
  }
  public OpenShiftControllerManagerFluentImpl.StatusNested<A> editOrNewStatusLike(OpenShiftControllerManagerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftControllerManagerFluentImpl that = (OpenShiftControllerManagerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OpenShiftControllerManagerFluentImpl.MetadataNested<N>> implements OpenShiftControllerManagerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OpenShiftControllerManagerSpecFluentImpl<OpenShiftControllerManagerFluentImpl.SpecNested<N>> implements OpenShiftControllerManagerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OpenShiftControllerManagerSpec item) {
      this.builder = new OpenShiftControllerManagerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OpenShiftControllerManagerSpecBuilder(this);
    }
    OpenShiftControllerManagerSpecBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OpenShiftControllerManagerStatusFluentImpl<OpenShiftControllerManagerFluentImpl.StatusNested<N>> implements OpenShiftControllerManagerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OpenShiftControllerManagerStatus item) {
      this.builder = new OpenShiftControllerManagerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OpenShiftControllerManagerStatusBuilder(this);
    }
    OpenShiftControllerManagerStatusBuilder builder;
    public N and() {
      return (N) OpenShiftControllerManagerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
